Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(15)

Unified Diff: chrome/common/extensions/permissions/chrome_api_permissions.cc

Issue 23146016: Add support for directory access to the file system API. (Closed) Base URL: http://git.chromium.org/chromium/src.git@simpler-write-permissions
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/extensions/permissions/chrome_api_permissions.cc
diff --git a/chrome/common/extensions/permissions/chrome_api_permissions.cc b/chrome/common/extensions/permissions/chrome_api_permissions.cc
index 1aa77db67258ddd6d69060fc0d22b4fee6c47fe4..006354de7a6b0d8eb00a1fe50b6d34346247a64b 100644
--- a/chrome/common/extensions/permissions/chrome_api_permissions.cc
+++ b/chrome/common/extensions/permissions/chrome_api_permissions.cc
@@ -268,11 +268,16 @@ std::vector<APIPermissionInfo*> ChromeAPIPermissions::GetAllPermissions()
APIPermissionInfo::kFlagNone,
IDS_EXTENSION_PROMPT_WARNING_VIDEO_CAPTURE,
PermissionMessage::kVideoCapture },
// The permission string for "fileSystem" is only shown when "write" is
// present. Read-only access is only granted after the user has been shown
// a file chooser dialog and selected a file. Selecting the file is
// considered consent to read it.
{ APIPermission::kFileSystem, "fileSystem" },
+ { APIPermission::kFileSystemDirectory, "fileSystem.directory",
+ APIPermissionInfo::kFlagNone,
+ IDS_EXTENSION_PROMPT_WARNING_FILE_SYSTEM_DIRECTORY,
+ PermissionMessage::kFileSystemDirectory },
{ APIPermission::kFileSystemRetainEntries, "fileSystem.retainEntries" },
{ APIPermission::kFileSystemWrite, "fileSystem.write",
APIPermissionInfo::kFlagNone,
@@ -268,11 +268,16 @@ std::vector<APIPermissionInfo*> ChromeAPIPermissions::GetAllPermissions()
IDS_EXTENSION_PROMPT_WARNING_VIDEO_CAPTURE,
PermissionMessage::kVideoCapture },
- // The permission string for "fileSystem" is only shown when "write" is
- // present. Read-only access is only granted after the user has been shown
- // a file chooser dialog and selected a file. Selecting the file is
- // considered consent to read it.
+ // The permission string for "fileSystem" is only shown when "write" or
+ // "directory" is present. Read-only access is only granted after the user
+ // has been shown a file or directory chooser dialog and selected a file or
+ // directory . Selecting the file or directory is considered consent to
+ // read it.
{ APIPermission::kFileSystem, "fileSystem" },
« no previous file with comments | « chrome/common/extensions/permissions/api_permission.h ('k') | chrome/common/extensions/permissions/permission_message.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698